# dependencies
require 'rubygems'
require 'minitest'
require 'minitest/autorun'

# Gem under test
require 'outcome'

describe Outcome do

  describe '#initialize and accessors' do
    let(:outcome) { Outcome.new(true, 'result', ['message'], ['error'], ['warning']) }
    [
      [:success, true],
      [:result, 'result'],
      [:messages, ['message']],
      [:errors, ['error']],
      [:warnings, ['warning']],
    ].each do |attr, expectation|
      it "has the #{ attr } attribute" do
        outcome.send(attr).must_equal(expectation)
      end
    end
  end

  describe '#success' do
    it 'handles true' do
      Outcome.new(true, nil).success?.must_equal true
    end

    it 'handles false' do
      Outcome.new(false, nil).success?.must_equal false
    end
  end

  describe '#messages_to_html' do
    it 'returns messages as a string, each on a new line' do
      Outcome.new(true, nil, %w[m1 m2 m3]).messages_to_html.must_equal(
        'm1<br/>m2<br/>m3'
      )
    end
  end

end
